@@ -1,8 +1,8 @@
 # File	   : Bzip2.pm
 # Author   : Rob Janes
 # Created  : 14 April 2005
-# Modified : 1 May 2005
-# Version  : 2.07
+# Modified : 2013-03-25 17:35:13 rurban
+# Version  : 2.10
 #
 #     Copyright (c) 2005 Rob Janes. All rights reserved.
 #     This program is free software; you can redistribute it and/or
@@ -130,7 +130,7 @@ $EXPORT_TAGS{'all'} = [ @EXPORT_OK ];
 
 our @EXPORT = ( @{ $EXPORT_TAGS{'utilities'} }, @{ $EXPORT_TAGS{'constants'} } );
 
-our $VERSION = "2.08";
+our $VERSION = "2.10";
 
 our $bzerrno = "";
 our $gzerrno;
@@ -706,7 +706,7 @@ Compress::Bzip2 - Interface to Bzip2 compression library
 
     $bytesread = $bz->bzread($buffer [,$size]) ;
     $bytesread = $bz->bzreadline($line);
-    $byteswritten = $bz->bzwrite($buffer);
+    $byteswritten = $bz->bzwrite($buffer [,$limit]);
     $errstring = $bz->bzerror(); 
     $status = $bz->bzeof();
     $status = $bz->bzflush();
@@ -741,8 +741,6 @@ I<bzip2> files. Unfortunately, most of them are not suitable.  So, this
 module provides another interface, built over top of the low level bzlib
 methods.
 
-=over 5
-
 =head2 B<$bz = bzopen(filename or filehandle, mode)>
 
 This function returns an object which is used to access the other
@@ -755,6 +753,9 @@ If a reference to an open filehandle is passed in place of the
 filename, it better be positioned to the start of a
 compression/decompression sequence.
 
+WARNING: With Perl 5.6 you cannot use a filehandle because of
+SEGV in destruction with bzclose or an implicit close.
+
 =head2 B<$bz = Compress::Bzip2-E<gt>new( [PARAMS] )>
 
 Create a Compress::Bzip2 object.  Optionally, provide
@@ -788,11 +789,14 @@ At this time B<bzreadline> ignores the variable C<$/>
 (C<$INPUT_RECORD_SEPARATOR> or C<$RS> when C<English> is in use). The
 end of a line is denoted by the C character C<'\n'>.
 
-=head2 B<$byteswritten = $bz-E<gt>bzwrite($buffer) ;>
+=head2 B<$byteswritten = $bz-E<gt>bzwrite($buffer [, $limit]) ;>
 
 Writes the contents of B<$buffer> to the compressed file. Returns the
 number of bytes actually written, or 0 on error.
 
+If $limit is given and non-zero, then only that many bytes from
+$buffer will be written.
+
 =head2 B<$status = $bz-E<gt>bzflush($flush) ;>
 
 Flushes all pending output to the compressed file.
@@ -912,7 +916,10 @@ I<an> error in numeric context. Use B<bzerror()> to check for specific
 I<bzlib> errors. The I<bzcat> example below shows how the variable can
 be used safely.
 
-=back
+=head2 B<$bz-E<gt>prefix>
+
+Returns the additional 5 byte header which is prepended to the bzip2
+header  starting with C<BZh> when using memBzip/compress.
 
 =head1 Compress::Bzip2 1.03 COMPATIBILITY
 
@@ -921,12 +928,10 @@ came to a head at 1.03.  The 1.03 version worked with bzlib 1.0.2, had
 improvements to the error handling, single buffer inflate/deflate, a
 streaming interface to inflate/deflate, and a cpan style test suite.
 
-=over 5
-
 =head2 B<$dest = compress( $string, [$level] )>
 
 Alias to memBzip, this compresses string, using the optional
-compression level, 1 through 9, the default being 1.  Returns a string
+compression level, 1 through 9, the default being 6.  Returns a string
 containing the compressed data.
 
 On error I<undef> is returned.
@@ -954,31 +959,29 @@ changeable.
 Alias to bzinflateInit.  See bzinflateInit for a description of the parameters.
 The option "-buffer" is accepted, but ignored.
 
-=head2 B<$output = $stream->add( $string )>
+=head2 B<$output = $stream-E<gt>add( $string )>
 
 Add data to be compressed/decompressed.  Returns whatever output is available
 (possibly none, if it's still buffering it), or undef on error.
 
-=head2 B<$output = $stream->finish( [$string] )>
+=head2 B<$output = $stream-E<gt>finish( [$string] )>
 
 Finish the operation; takes an optional final data string.  Whatever is
 returned completes the output; returns undef on error.
 
-=head2 B<$stream->error>
+=head2 B<$stream-E<gt>error>
 
 Like the function, but applies to the current object only.  Note that errors
 in a stream object are also returned by the function.
 
-=head2 B<$stream->input_size>
+=head2 B<$stream-E<gt>input_size>
 
 Alias to total_in.  Total bytes passed to the stream.
 
-=head2 B<$stream->output_size>
+=head2 B<$stream-E<gt>output_size>
 
 Alias to total_out.  Total bytes received from the stream.
 
-=back
-
 =head1 GZIP COMPATIBILITY INTERFACE
 
 Except for the exact state and error numbers, this package presents an
@@ -1003,8 +1006,6 @@ to
 Some of the Compress::Zlib aliases don't return anything useful, like
 crc32 or adler32, cause bzip2 doesn't do that sort of thing.
 
-=over 5
-
 =head2 B< $gz = gzopen( $filename, $mode ) >
 
 Alias for bzopen.
@@ -1099,29 +1100,25 @@ Alias for memBzip.
 
 Alias for memBunzip.
 
-=back
-
 =head1 IN-MEMORY COMPRESS/UNCOMPRESS
 
 Two high-level functions are provided by I<bzlib> to perform in-memory
 compression. They are B<memBzip> and B<memBunzip>. Two Perl subs are
 provided which provide similar functionality.
 
-=over 5
-
 =head2 B<$compressed = memBzip($buffer);>
 
-Compresses B<$source>. If successful it returns the compressed
+Compresses B<$buffer>. If successful it returns the compressed
 data. Otherwise it returns I<undef>.
 
 The buffer parameter can either be a scalar or a scalar reference.
 
 Essentially, an in-memory bzip file is created. It creates a minimal
-bzip header.
+bzip header, which adds 5 bytes before the bzip2 specific BZh header.
 
 =head2 B<$uncompressed = memBunzip($buffer);>
 
-Uncompresses B<$source>. If successful it returns the uncompressed
+Uncompresses B<$buffer>. If successful it returns the uncompressed
 data. Otherwise it returns I<undef>.
 
 The source buffer can either be a scalar or a scalar reference.
@@ -1130,8 +1127,6 @@ The buffer parameter can either be a scalar or a scalar reference. The
 contents of the buffer parameter are destroyed after calling this
 function.
 
-=back
-
 =head1 STREAM DEFLATE 
 
 The Perl interface will I<always> consume the complete input buffer
@@ -1294,13 +1289,13 @@ I<bzlib.h> error code.
 The function optionally takes a number of named options specified as
 C<-Name=E<gt>value> pairs. This allows individual options to be
 tailored without having to specify them all in the parameter list.
- 
+
 For backward compatibility, it is also possible to pass the parameters
 as a reference to a hash containing the name=>value pairs.
- 
+
 The function takes one optional parameter, a reference to a hash.  The
 contents of the hash allow the deflation interface to be tailored.
- 
+
 Here is a list of the valid options:
 
 =over 5
@@ -1376,8 +1371,6 @@ Here is an example of using B<bzinflate>.
 
 Here are some example scripts of using the interface.
 
-=over 5
-
 =head2 B<A bzcat function>
 
   use strict ;
@@ -1452,8 +1445,6 @@ output.
 
   $bz->bzclose ;
 
-=back
-
 =head1 EXPORT
 
 Use the tags :all, :utilities, :constants, :bzip1 and :gzip.
@@ -1534,7 +1525,7 @@ The documentation for zlib, bzip2 and Compress::Zlib.
 
 =head1 AUTHOR
 
-Rob Janes, E<lt>rwjanes at primus.caE<gt>
+Rob Janes, E<lt>arjay at cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -1561,7 +1552,7 @@ streaming interface and error information were added by David Robins
 F<dbrobins@davidrobins.net>.
 
 Version 2 of I<Compress::Bzip2> is due to Rob Janes, of
-rwjanes@primus.ca.  This release is intended to give an interface
+arjay@cpan.org.  This release is intended to give an interface
 close to that of Compress::Zlib.  It's development forks from 1.00,
 not 1.03, so the streaming interface is not the same as that in 1.03,
 although apparently compatible as it passes the 1.03 test suite.
